# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GoalTypeEnum",
        "UnitTypeEnum",
    },
)


class GoalTypeEnum(proto.Message):
    r"""Wrapper message for
    [GoalType][google.ads.admanager.v1.GoalTypeEnum.GoalType].

    """

    class GoalType(proto.Enum):
        r"""Specifies the type of the goal for a LineItem.

        Values:
            GOAL_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            NONE (1):
                No goal is specified for the number of ads delivered. The
                line item
                [type][google.ads.admanager.v1.LineItem.line_item_type] must
                be one of:

                - [LineItemTypeEnum.LineItemType.PRICE_PRIORITY][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.PRICE_PRIORITY]
                - [LineItemTypeEnum.LineItemType.AD_EXCHANGE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.AD_EXCHANGE]
                - [LineItemTypeEnum.LineItemType.CLICK_TRACKING][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.CLICK_TRACKING]
            LIFETIME (2):
                There is a goal on the number of ads delivered for this line
                item during its entire lifetime. The line item
                [type][google.ads.admanager.v1.LineItem.line_item_type] must
                be one of:

                - [LineItemTypeEnum.LineItemType.STANDARD][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.STANDARD]
                - [LineItemTypeEnum.LineItemType.BULK][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.BULK]
                - [LineItemTypeEnum.LineItemType.PRICE_PRIORITY][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.PRICE_PRIORITY]
                - [LineItemTypeEnum.LineItemType.ADSENSE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.ADSENSE]
                - [LineItemTypeEnum.LineItemType.AD_EXCHANGE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.AD_EXCHANGE]
                - [LineItemTypeEnum.LineItemType.ADMOB][]
                - [LineItemTypeEnum.LineItemType.CLICK_TRACKING][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.CLICK_TRACKING]
            DAILY (3):
                There is a daily goal on the number of ads delivered for
                this line item. The line item
                [type][google.ads.admanager.v1.LineItem.line_item_type] must
                be one of:

                - [LineItemTypeEnum.LineItemType.SPONSORSHIP][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.SPONSORSHIP]
                - [LineItemTypeEnum.LineItemType.NETWORK][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.NETWORK]
                - [LineItemTypeEnum.LineItemType.PRICE_PRIORITY][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.PRICE_PRIORITY]
                - [LineItemTypeEnum.LineItemType.HOUSE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.HOUSE]
                - [LineItemTypeEnum.LineItemType.ADSENSE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.ADSENSE]
                - [LineItemTypeEnum.LineItemType.AD_EXCHANGE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.AD_EXCHANGE]
                - [LineItemTypeEnum.LineItemType.ADMOB][]
                - [LineItemTypeEnum.LineItemType.BUMPER][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.BUMPER]
        """
        GOAL_TYPE_UNSPECIFIED = 0
        NONE = 1
        LIFETIME = 2
        DAILY = 3


class UnitTypeEnum(proto.Message):
    r"""Wrapper message for
    [UnitType][google.ads.admanager.v1.UnitTypeEnum.UnitType].

    """

    class UnitType(proto.Enum):
        r"""Indicates the type of unit used for defining a reservation. The
        [LineItem.cost_type][] can differ from the UnitType - an ad can have
        an impression goal, but be billed by its click. Usually CostType and
        UnitType will refer to the same unit.

        Values:
            UNIT_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            IMPRESSIONS (1):
                The number of impressions served by creatives
                associated with the line item.
            CLICKS (2):
                The number of clicks reported by creatives associated with
                the line item. The line item
                [type][google.ads.admanager.v1.LineItem.line_item_type] must
                be one of:

                - [LineItemTypeEnum.LineItemType.STANDARD][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.STANDARD]
                - [LineItemTypeEnum.LineItemType.BULK][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.BULK]
                - [LineItemTypeEnum.LineItemType.PRICE_PRIORITY][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.PRICE_PRIORITY]
            CLICK_THROUGH_CPA_CONVERSIONS (3):
                The number of click-through Cost-Per-Action (CPA)
                conversions from creatives associated with the line item.
                This is only supported as secondary goal and the
                [LineItem.cost_type][] must be
                [CostTypeEnum.CostType.CPA][].
            VIEW_THROUGH_CPA_CONVERSIONS (4):
                The number of view-through Cost-Per-Action (CPA) conversions
                from creatives associated with the line item. This is only
                supported as secondary goal and the [LineItem.cost_type][]
                must be [CostTypeEnum.CostType.CPA}.
            TOTAL_CPA_CONVERSIONS (5):
                The number of total Cost-Per-Action (CPA) conversions from
                creatives associated with the line item. This is only
                supported as secondary goal and the [LineItem.cost_type}
                must be [CostTypeEnum.CostType.CPA}.
            VIEWABLE_IMPRESSIONS (6):
                The number of viewable impressions reported by creatives
                associated with the line item. The
                [LineItem.line_item_type][google.ads.admanager.v1.LineItem.line_item_type]
                must be
                [LineItemTypeEnum.LineItemType.STANDARD][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.STANDARD].
            IN_TARGET_IMPRESSIONS (7):
                The number of in-target impressions reported by third party
                measurements. The
                [LineItem.line_item_type][google.ads.admanager.v1.LineItem.line_item_type]
                must be
                [LineItemTypeEnum.LineItemType.STANDARD][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.STANDARD].
        """
        UNIT_TYPE_UNSPECIFIED = 0
        IMPRESSIONS = 1
        CLICKS = 2
        CLICK_THROUGH_CPA_CONVERSIONS = 3
        VIEW_THROUGH_CPA_CONVERSIONS = 4
        TOTAL_CPA_CONVERSIONS = 5
        VIEWABLE_IMPRESSIONS = 6
        IN_TARGET_IMPRESSIONS = 7


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "ExchangeSyndicationProductEnum",
    },
)


class ExchangeSyndicationProductEnum(proto.Message):
    r"""Wrapper message for
    [ExchangeSyndicationProduct][google.ads.admanager.v1.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct]

    """

    class ExchangeSyndicationProduct(proto.Enum):
        r"""Ad Exchange syndication product.

        Values:
            EXCHANGE_SYNDICATION_PRODUCT_UNSPECIFIED (0):
                No value specified
            DISPLAY (1):
                Property serves in-browser.
            MOBILE_APP (2):
                Property serves on mobile applications
                (includes JS and SDK).
            VIDEO_AND_AUDIO (3):
                Property serves video (includes audio).
            GAMES (4):
                Property serves for games.
        """
        EXCHANGE_SYNDICATION_PRODUCT_UNSPECIFIED = 0
        DISPLAY = 1
        MOBILE_APP = 2
        VIDEO_AND_AUDIO = 3
        GAMES = 4


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "VideoPositionEnum",
    },
)


class VideoPositionEnum(proto.Message):
    r"""Wrapper message for
    [VideoPosition][google.ads.admanager.v1.VideoPositionEnum.VideoPosition]

    """

    class VideoPosition(proto.Enum):
        r"""Represents a targetable position within a video.

        Values:
            VIDEO_POSITION_UNSPECIFIED (0):
                Default value. This value is unused.
            ALL (1):
                Allow ad placement at any position within the
                video.
            MIDROLL (2):
                Target ad placement during the video.
            POSTROLL (3):
                Target ad placement after the video ends.
            PREROLL (4):
                Target ad placement before the video starts.
        """
        VIDEO_POSITION_UNSPECIFIED = 0
        ALL = 1
        MIDROLL = 2
        POSTROLL = 3
        PREROLL = 4


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import size_type_enum

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Size",
    },
)


class Size(proto.Message):
    r"""Represents the dimensions of an AdUnit, LineItem, or
    Creative.

    Attributes:
        width (int):
            Required. The width of the Creative,
            [AdUnit][google.ads.admanager.v1.AdUnit], or LineItem.
        height (int):
            Required. The height of the Creative,
            [AdUnit][google.ads.admanager.v1.AdUnit], or LineItem.
        size_type (google.ads.admanager_v1.types.SizeTypeEnum.SizeType):
            Required. The SizeType of the Creative,
            [AdUnit][google.ads.admanager.v1.AdUnit], or LineItem.
    """

    width: int = proto.Field(
        proto.INT32,
        number=1,
    )
    height: int = proto.Field(
        proto.INT32,
        number=2,
    )
    size_type: size_type_enum.SizeTypeEnum.SizeType = proto.Field(
        proto.ENUM,
        number=3,
        enum=size_type_enum.SizeTypeEnum.SizeType,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import (
    ad_unit_enums,
    applied_label,
    environment_type_enum,
)
from google.ads.admanager_v1.types import frequency_cap as gaa_frequency_cap
from google.ads.admanager_v1.types import size as gaa_size

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "AdUnit",
        "AdUnitSize",
        "AdUnitParent",
        "LabelFrequencyCap",
    },
)


class AdUnit(proto.Message):
    r"""The AdUnit resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the AdUnit. Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``
        ad_unit_id (int):
            Output only. AdUnit ID.
        parent_ad_unit (str):
            Required. Immutable. The AdUnit's parent. Every ad unit has
            a parent except for the root ad unit, which is created by
            Google. Format:
            "networks/{network_code}/adUnits/{ad_unit_id}".

            This field is a member of `oneof`_ ``_parent_ad_unit``.
        parent_path (MutableSequence[google.ads.admanager_v1.types.AdUnitParent]):
            Output only. The path to this AdUnit in the
            ad unit hierarchy represented as a list from the
            root to this ad unit's parent. For root ad
            units, this list is empty.
        display_name (str):
            Required. The display name of the ad unit.
            Its maximum length is 255 characters.

            This field is a member of `oneof`_ ``_display_name``.
        ad_unit_code (str):
            Optional. Immutable. A string used to
            uniquely identify the ad unit for the purposes
            of serving the ad. This attribute can be set
            during ad unit creation. If it is not provided,
            it will be assigned by Google based on the ad
            unit ID.

            This field is a member of `oneof`_ ``_ad_unit_code``.
        status (google.ads.admanager_v1.types.AdUnitStatusEnum.AdUnitStatus):
            Output only. The status of this ad unit.  It
            defaults to ACTIVE.

            This field is a member of `oneof`_ ``_status``.
        applied_target_window (google.ads.admanager_v1.types.TargetWindowEnum.TargetWindow):
            Optional. The target window directly applied
            to this AdUnit. If this field is not set, this
            AdUnit uses the target window specified in
            effectiveTargetWindow.

            This field is a member of `oneof`_ ``_applied_target_window``.
        effective_target_window (google.ads.admanager_v1.types.TargetWindowEnum.TargetWindow):
            Output only. Non-empty default. The target
            window of this AdUnit. This value is inherited
            from ancestor AdUnits and defaults to TOP if no
            AdUnit in the hierarchy specifies it.

            This field is a member of `oneof`_ ``_effective_target_window``.
        applied_teams (MutableSequence[str]):
            Optional. The resource names of Teams directly applied to
            this AdUnit. Format:
            "networks/{network_code}/teams/{team_id}".
        teams (MutableSequence[str]):
            Output only. The resource names of all Teams that this
            AdUnit is on as well as those inherited from parent AdUnits.
            Format: "networks/{network_code}/teams/{team_id}".
        description (str):
            Optional. A description of the ad unit. The
            maximum length is 65,535 characters.

            This field is a member of `oneof`_ ``_description``.
        explicitly_targeted (bool):
            Optional. If this field is set to true, then
            the AdUnit will not be implicitly targeted when
            its parent is. Traffickers must explicitly
            target such an AdUnit or else no line items will
            serve to it. This feature is only available for
            Ad Manager 360 accounts.

            This field is a member of `oneof`_ ``_explicitly_targeted``.
        has_children (bool):
            Output only. This field is set to true if the
            ad unit has any children.

            This field is a member of `oneof`_ ``_has_children``.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time this AdUnit was last
            modified.

            This field is a member of `oneof`_ ``_update_time``.
        ad_unit_sizes (MutableSequence[google.ads.admanager_v1.types.AdUnitSize]):
            Optional. The sizes that can be served inside
            this ad unit.
        external_set_top_box_channel_id (str):
            Optional. Determines what set top box video
            on demand channel this ad unit corresponds to in
            an external set top box ad campaign system.

            This field is a member of `oneof`_ ``_external_set_top_box_channel_id``.
        refresh_delay (google.protobuf.duration_pb2.Duration):
            Optional. The duration after which an Ad Unit
            will automatically refresh. This is only valid
            for ad units in mobile apps. If not set, the ad
            unit will not refresh.

            This field is a member of `oneof`_ ``_refresh_delay``.
        applied_labels (MutableSequence[google.ads.admanager_v1.types.AppliedLabel]):
            Optional. The set of labels applied directly
            to this ad unit.
        effective_applied_labels (MutableSequence[google.ads.admanager_v1.types.AppliedLabel]):
            Output only. Contains the set of labels
            applied directly to the ad unit as well as those
            inherited from the parent ad units. If a label
            has been negated, only the negated label is
            returned. This attribute is assigned by Google.
        applied_label_frequency_caps (MutableSequence[google.ads.admanager_v1.types.LabelFrequencyCap]):
            Optional. The set of label frequency caps
            applied directly to this ad unit. There is a
            limit of 10 label frequency caps per ad unit.
        effective_label_frequency_caps (MutableSequence[google.ads.admanager_v1.types.LabelFrequencyCap]):
            Output only. The label frequency caps applied
            directly to the ad unit as well as those
            inherited from parent ad units.
        smart_size_mode (google.ads.admanager_v1.types.SmartSizeModeEnum.SmartSizeMode):
            Optional. Non-empty default. The smart size
            mode for this ad unit. This attribute defaults
            to SmartSizeMode.NONE for fixed sizes.

            This field is a member of `oneof`_ ``_smart_size_mode``.
        applied_adsense_enabled (bool):
            Optional. The value of AdSense enabled
            directly applied to this ad unit. If not
            specified this ad unit will inherit the value of
            effectiveAdsenseEnabled from its ancestors.

            This field is a member of `oneof`_ ``_applied_adsense_enabled``.
        effective_adsense_enabled (bool):
            Output only. Specifies whether or not the
            AdUnit is enabled for serving ads from the
            AdSense content network. This attribute defaults
            to the ad unit's parent or ancestor's setting if
            one has been set. If no ancestor of the ad unit
            has set appliedAdsenseEnabled, the attribute is
            defaulted to true.

            This field is a member of `oneof`_ ``_effective_adsense_enabled``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ad_unit_id: int = proto.Field(
        proto.INT64,
        number=15,
    )
    parent_ad_unit: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    parent_path: MutableSequence["AdUnitParent"] = proto.RepeatedField(
        proto.MESSAGE,
        number=11,
        message="AdUnitParent",
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    ad_unit_code: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    status: ad_unit_enums.AdUnitStatusEnum.AdUnitStatus = proto.Field(
        proto.ENUM,
        number=13,
        optional=True,
        enum=ad_unit_enums.AdUnitStatusEnum.AdUnitStatus,
    )
    applied_target_window: ad_unit_enums.TargetWindowEnum.TargetWindow = proto.Field(
        proto.ENUM,
        number=44,
        optional=True,
        enum=ad_unit_enums.TargetWindowEnum.TargetWindow,
    )
    effective_target_window: ad_unit_enums.TargetWindowEnum.TargetWindow = proto.Field(
        proto.ENUM,
        number=45,
        optional=True,
        enum=ad_unit_enums.TargetWindowEnum.TargetWindow,
    )
    applied_teams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    teams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )
    description: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    explicitly_targeted: bool = proto.Field(
        proto.BOOL,
        number=6,
        optional=True,
    )
    has_children: bool = proto.Field(
        proto.BOOL,
        number=7,
        optional=True,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    ad_unit_sizes: MutableSequence["AdUnitSize"] = proto.RepeatedField(
        proto.MESSAGE,
        number=14,
        message="AdUnitSize",
    )
    external_set_top_box_channel_id: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    refresh_delay: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=19,
        optional=True,
        message=duration_pb2.Duration,
    )
    applied_labels: MutableSequence[applied_label.AppliedLabel] = proto.RepeatedField(
        proto.MESSAGE,
        number=21,
        message=applied_label.AppliedLabel,
    )
    effective_applied_labels: MutableSequence[
        applied_label.AppliedLabel
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=22,
        message=applied_label.AppliedLabel,
    )
    applied_label_frequency_caps: MutableSequence[
        "LabelFrequencyCap"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=23,
        message="LabelFrequencyCap",
    )
    effective_label_frequency_caps: MutableSequence[
        "LabelFrequencyCap"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=24,
        message="LabelFrequencyCap",
    )
    smart_size_mode: ad_unit_enums.SmartSizeModeEnum.SmartSizeMode = proto.Field(
        proto.ENUM,
        number=25,
        optional=True,
        enum=ad_unit_enums.SmartSizeModeEnum.SmartSizeMode,
    )
    applied_adsense_enabled: bool = proto.Field(
        proto.BOOL,
        number=26,
        optional=True,
    )
    effective_adsense_enabled: bool = proto.Field(
        proto.BOOL,
        number=27,
        optional=True,
    )


class AdUnitSize(proto.Message):
    r"""Represents the size, environment, and companions of an ad in
    an ad unit.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        size (google.ads.admanager_v1.types.Size):
            Required. The Size of the AdUnit.

            This field is a member of `oneof`_ ``_size``.
        environment_type (google.ads.admanager_v1.types.EnvironmentTypeEnum.EnvironmentType):
            Required. The EnvironmentType of the AdUnit

            This field is a member of `oneof`_ ``_environment_type``.
        companions (MutableSequence[google.ads.admanager_v1.types.Size]):
            The companions for this ad unit size. Companions are only
            valid if the environment is
            [VIDEO_PLAYER][google.ads.admanager.v1.EnvironmentTypeEnum.EnvironmentType].
    """

    size: gaa_size.Size = proto.Field(
        proto.MESSAGE,
        number=1,
        optional=True,
        message=gaa_size.Size,
    )
    environment_type: environment_type_enum.EnvironmentTypeEnum.EnvironmentType = (
        proto.Field(
            proto.ENUM,
            number=2,
            optional=True,
            enum=environment_type_enum.EnvironmentTypeEnum.EnvironmentType,
        )
    )
    companions: MutableSequence[gaa_size.Size] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message=gaa_size.Size,
    )


class AdUnitParent(proto.Message):
    r"""The summary of a parent AdUnit.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        parent_ad_unit (str):
            Output only. The parent of the current AdUnit Format:
            ``networks/{network_code}/adUnits/{ad_unit_id}``

            This field is a member of `oneof`_ ``_parent_ad_unit``.
        display_name (str):
            Output only. The display name of the parent
            AdUnit.

            This field is a member of `oneof`_ ``_display_name``.
        ad_unit_code (str):
            Output only. A string used to uniquely
            identify the ad unit for the purposes of serving
            the ad.

            This field is a member of `oneof`_ ``_ad_unit_code``.
    """

    parent_ad_unit: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    ad_unit_code: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )


class LabelFrequencyCap(proto.Message):
    r"""Frequency cap using a label.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        label (str):
            Required. The label to used for frequency capping. Format:
            "networks/{network_code}/labels/{label_id}".

            This field is a member of `oneof`_ ``_label``.
        frequency_cap (google.ads.admanager_v1.types.FrequencyCap):
            The frequency cap.

            This field is a member of `oneof`_ ``_frequency_cap``.
    """

    label: str = proto.Field(
        proto.STRING,
        number=1,
        optional=True,
    )
    frequency_cap: gaa_frequency_cap.FrequencyCap = proto.Field(
        proto.MESSAGE,
        number=2,
        optional=True,
        message=gaa_frequency_cap.FrequencyCap,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import contact_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Contact",
    },
)


class Contact(proto.Message):
    r"""A contact represents a person who is affiliated with a single
    company. A contact can have a variety of contact information
    associated to it, and can be invited to view their company's
    orders, line items, creatives, and reports.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Contact``. Format:
            ``networks/{network_code}/contacts/{contact_id}``
        display_name (str):
            Required. The name of the contact. This
            attribute has a maximum length of 127
            characters.

            This field is a member of `oneof`_ ``_display_name``.
        company (str):
            Required. Immutable. The resource name of the Company.
            Format: "networks/{network_code}/companies/{company_id}".

            This field is a member of `oneof`_ ``_company``.
        status (google.ads.admanager_v1.types.ContactStatusEnum.ContactStatus):
            Output only. The status of the contact. This
            attribute is assigned by Google.

            This field is a member of `oneof`_ ``_status``.
        address (str):
            Optional. The address of the contact. This
            attribute has a maximum length of 1024
            characters.

            This field is a member of `oneof`_ ``_address``.
        cell_phone (str):
            Optional. The cell phone number where the
            contact can be reached.

            This field is a member of `oneof`_ ``_cell_phone``.
        comment (str):
            Optional. A free-form text comment for the
            contact. This attribute has a maximum length of
            1024 characters.

            This field is a member of `oneof`_ ``_comment``.
        email (str):
            Optional. The e-mail address where the
            contact can be reached. This attribute has a
            maximum length of 128 characters.

            This field is a member of `oneof`_ ``_email``.
        fax (str):
            Optional. The fax number where the contact
            can be reached. This attribute has a maximum
            length of 1024 characters.

            This field is a member of `oneof`_ ``_fax``.
        title (str):
            Optional. The job title of the contact. This
            attribute has a maximum length of 1024
            characters.

            This field is a member of `oneof`_ ``_title``.
        work_phone (str):
            Optional. The work phone number where the
            contact can be reached. This attribute has a
            maximum length of 1024 characters.

            This field is a member of `oneof`_ ``_work_phone``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    company: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    status: contact_enums.ContactStatusEnum.ContactStatus = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=contact_enums.ContactStatusEnum.ContactStatus,
    )
    address: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    cell_phone: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    comment: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    email: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    fax: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    title: str = proto.Field(
        proto.STRING,
        number=12,
        optional=True,
    )
    work_phone: str = proto.Field(
        proto.STRING,
        number=13,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import applied_label, custom_field_value, order_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Order",
    },
)


class Order(proto.Message):
    r"""The ``Order`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``Order``. Format:
            ``networks/{network_code}/orders/{order_id}``
        order_id (int):
            Output only. Order ID.

            This field is a member of `oneof`_ ``_order_id``.
        display_name (str):
            Required. The display name of the Order.
            This value has a maximum length of 255
            characters.

            This field is a member of `oneof`_ ``_display_name``.
        programmatic (bool):
            Optional. Specifies whether or not the Order
            is a programmatic order.

            This field is a member of `oneof`_ ``_programmatic``.
        trafficker (str):
            Required. The resource name of the User responsible for
            trafficking the Order. Format:
            "networks/{network_code}/users/{user_id}".

            This field is a member of `oneof`_ ``_trafficker``.
        advertiser_contacts (MutableSequence[str]):
            Optional. Unordered list. The resource names of Contacts
            from the advertiser of this Order. Format:
            "networks/{network_code}/contacts/{contact_id}".
        advertiser (str):
            Required. The resource name of the Company, which is of type
            Company.Type.ADVERTISER, to which this order belongs.
            Format: "networks/{network_code}/companies/{company_id}".

            This field is a member of `oneof`_ ``_advertiser``.
        agency_contacts (MutableSequence[str]):
            Optional. The resource names of Contacts from the
            advertising Agency of this Order. Format:
            "networks/{network_code}/contacts/{contact_id}".
        agency (str):
            Optional. The resource name of the Company, which is of type
            Company.Type.AGENCY, with which this order is associated.
            Format: "networks/{network_code}/companies/{company_id}".

            This field is a member of `oneof`_ ``_agency``.
        applied_teams (MutableSequence[str]):
            Optional. The resource names of Teams directly applied to
            this Order. Format:
            "networks/{network_code}/teams/{team_id}".
        effective_teams (MutableSequence[str]):
            Output only. The resource names of Teams applied to this
            Order including inherited values. Format:
            "networks/{network_code}/teams/{team_id}".
        creator (str):
            Output only. The resource name of the User who created the
            Order on behalf of the advertiser. Format:
            "networks/{network_code}/users/{user_id}".

            This field is a member of `oneof`_ ``_creator``.
        currency_code (str):
            Output only. The ISO 4217 3-letter currency
            code for the currency used by the Order. This
            value is the network's currency code.

            This field is a member of `oneof`_ ``_currency_code``.
        start_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the Order and its
            associated Line items are eligible to begin serving. This
            attribute is derived from the Line item of the order that
            has the earliest ``LineItem.start_time``.

            This field is a member of `oneof`_ ``_start_time``.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the Order and its
            associated Line items stop being served. This attribute is
            derived from the Line item of the order that has the latest
            ``LineItem.end_time``.

            This field is a member of `oneof`_ ``_end_time``.
        unlimited_end_time (bool):
            Output only. Indicates whether or not this
            Order has an end time.

            This field is a member of `oneof`_ ``_unlimited_end_time``.
        external_order_id (int):
            Optional. An arbitrary ID to associate to the
            Order, which can be used as a key to an external
            system.

            This field is a member of `oneof`_ ``_external_order_id``.
        archived (bool):
            Output only. The archival status of the
            Order.

            This field is a member of `oneof`_ ``_archived``.
        last_modified_by_app (str):
            Output only. The application which modified
            this order. This attribute is assigned by
            Google.

            This field is a member of `oneof`_ ``_last_modified_by_app``.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant this Order was last
            modified.

            This field is a member of `oneof`_ ``_update_time``.
        notes (str):
            Optional. Provides any additional notes that
            may annotate the Order. This attribute has a
            maximum length of 65,535 characters.

            This field is a member of `oneof`_ ``_notes``.
        po_number (str):
            Optional. The purchase order number for the
            Order. This value has a maximum length of 63
            characters.

            This field is a member of `oneof`_ ``_po_number``.
        status (google.ads.admanager_v1.types.OrderStatusEnum.OrderStatus):
            Output only. The status of the Order.

            This field is a member of `oneof`_ ``_status``.
        salesperson (str):
            Optional. The resource name of the User responsible for the
            sales of the Order. Format:
            "networks/{network_code}/users/{user_id}".

            This field is a member of `oneof`_ ``_salesperson``.
        secondary_salespeople (MutableSequence[str]):
            Optional. Unordered list. The resource names of the
            secondary salespeople associated with the order. Format:
            "networks/{network_code}/users/{user_id}".
        secondary_traffickers (MutableSequence[str]):
            Optional. Unordered list. The resource names of the
            secondary traffickers associated with the order. Format:
            "networks/{network_code}/users/{user_id}".
        applied_labels (MutableSequence[google.ads.admanager_v1.types.AppliedLabel]):
            Optional. The set of labels applied directly
            to this order.
        effective_applied_labels (MutableSequence[google.ads.admanager_v1.types.AppliedLabel]):
            Output only. Contains the set of labels
            applied directly to the order as well as those
            inherited from the company that owns the order.
            If a label has been negated, only the negated
            label is returned. This field is assigned by
            Google.
        custom_field_values (MutableSequence[google.ads.admanager_v1.types.CustomFieldValue]):
            Optional. The set of custom field values to
            this order.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    order_id: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    programmatic: bool = proto.Field(
        proto.BOOL,
        number=3,
        optional=True,
    )
    trafficker: str = proto.Field(
        proto.STRING,
        number=23,
        optional=True,
    )
    advertiser_contacts: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    advertiser: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    agency_contacts: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    agency: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    applied_teams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=9,
    )
    effective_teams: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=28,
    )
    creator: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    currency_code: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )
    start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=19,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=12,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    unlimited_end_time: bool = proto.Field(
        proto.BOOL,
        number=45,
        optional=True,
    )
    external_order_id: int = proto.Field(
        proto.INT32,
        number=13,
        optional=True,
    )
    archived: bool = proto.Field(
        proto.BOOL,
        number=14,
        optional=True,
    )
    last_modified_by_app: str = proto.Field(
        proto.STRING,
        number=15,
        optional=True,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=16,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    notes: str = proto.Field(
        proto.STRING,
        number=17,
        optional=True,
    )
    po_number: str = proto.Field(
        proto.STRING,
        number=18,
        optional=True,
    )
    status: order_enums.OrderStatusEnum.OrderStatus = proto.Field(
        proto.ENUM,
        number=20,
        optional=True,
        enum=order_enums.OrderStatusEnum.OrderStatus,
    )
    salesperson: str = proto.Field(
        proto.STRING,
        number=21,
        optional=True,
    )
    secondary_salespeople: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=22,
    )
    secondary_traffickers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=24,
    )
    applied_labels: MutableSequence[applied_label.AppliedLabel] = proto.RepeatedField(
        proto.MESSAGE,
        number=25,
        message=applied_label.AppliedLabel,
    )
    effective_applied_labels: MutableSequence[
        applied_label.AppliedLabel
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=26,
        message=applied_label.AppliedLabel,
    )
    custom_field_values: MutableSequence[
        custom_field_value.CustomFieldValue
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=38,
        message=custom_field_value.CustomFieldValue,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import goal_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Goal",
    },
)


class Goal(proto.Message):
    r"""Defines the criteria a [LineItem][google.ads.admanager.v1.LineItem]
    needs to satisfy to meet its delivery goal.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        goal_type (google.ads.admanager_v1.types.GoalTypeEnum.GoalType):
            The type of the goal for the LineItem. It
            defines the period over which the goal should be
            reached.

            This field is a member of `oneof`_ ``_goal_type``.
        unit_type (google.ads.admanager_v1.types.UnitTypeEnum.UnitType):
            The type of the goal unit for the LineItem.

            This field is a member of `oneof`_ ``_unit_type``.
        units (int):
            If this is a primary goal, it represents the number or
            percentage of impressions or clicks that will be reserved.
            If the line item is of type
            [LineItemTypeEnum.LineItemType.SPONSORSHIP][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.SPONSORSHIP],
            it represents the percentage of available impressions
            reserved. If the line item is of type
            [LineItemTypeEnum.LineItemType.BULK][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.BULK]
            or
            [LineItemTypeEnum.LineItemType.PRICE_PRIORITY][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.PRICE_PRIORITY],
            it represents the number of remaining impressions reserved.
            If the line item is of type
            [LineItemTypeEnum.LineItemType.NETWORK][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.NETWORK]
            or
            [LineItemTypeEnum.LineItemType.HOUSE][google.ads.admanager.v1.LineItemTypeEnum.LineItemType.HOUSE],
            it represents the percentage of remaining impressions
            reserved. If this is an impression cap goal, it represents
            the number of impressions or conversions that the line item
            will stop serving at if reached. For valid line item types,
            see [LineItem.impressions_cap][].

            This field is a member of `oneof`_ ``_units``.
    """

    goal_type: goal_enums.GoalTypeEnum.GoalType = proto.Field(
        proto.ENUM,
        number=1,
        optional=True,
        enum=goal_enums.GoalTypeEnum.GoalType,
    )
    unit_type: goal_enums.UnitTypeEnum.UnitType = proto.Field(
        proto.ENUM,
        number=2,
        optional=True,
        enum=goal_enums.UnitTypeEnum.UnitType,
    )
    units: int = proto.Field(
        proto.INT64,
        number=3,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import exchange_syndication_product_enum

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "WebProperty",
    },
)


class WebProperty(proto.Message):
    r"""Represents a web property.

    Attributes:
        name (str):
            Identifier. The resource name of the WebProperty. Format:
            ``networks/{network_code}/webProperties/{web_property_code}``
        web_property_code (str):
            Required. The ``WebProperty`` code.
        product_type (google.ads.admanager_v1.types.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct):
            Required. The ExchangeSyndicationProduct
            associated with this WebProperty.
        web_property_id (int):
            Optional. The ``WebProperty`` ID.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    web_property_code: str = proto.Field(
        proto.STRING,
        number=2,
    )
    product_type: exchange_syndication_product_enum.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct = proto.Field(
        proto.ENUM,
        number=3,
        enum=exchange_syndication_product_enum.ExchangeSyndicationProductEnum.ExchangeSyndicationProduct,
    )
    web_property_id: int = proto.Field(
        proto.INT64,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomFieldValue",
    },
)


class CustomFieldValue(proto.Message):
    r"""A value for a CustomField on a resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        custom_field (str):
            Required. The custom field for which this is a value.
            Format:
            "networks/{network_code}/customFields/{custom_field_id}".
        value (google.ads.admanager_v1.types.CustomFieldValue.Value):
            Required. A typed value representation of the
            value.

            This field is a member of `oneof`_ ``_value``.
    """

    class Value(proto.Message):
        r"""Represent custom field value type.

        This message has `oneof`_ fields (mutually exclusive fields).
        For each oneof, at most one member field can be set at the same time.
        Setting any member of the oneof automatically clears all other
        members.

        .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

        Attributes:
            dropdown_value (int):
                The custom_field_option_id, if the CustomFieldDataType is
                DROPDOWN.

                This field is a member of `oneof`_ ``value``.
            string_value (str):
                The value, if the CustomFieldDataType is
                STRING.

                This field is a member of `oneof`_ ``value``.
            number_value (float):
                The value, if the CustomFieldDataType is
                NUMBER.

                This field is a member of `oneof`_ ``value``.
            toggle_value (bool):
                The value, if the CustomFieldDataType is
                TOGGLE.

                This field is a member of `oneof`_ ``value``.
        """

        dropdown_value: int = proto.Field(
            proto.INT64,
            number=1,
            oneof="value",
        )
        string_value: str = proto.Field(
            proto.STRING,
            number=2,
            oneof="value",
        )
        number_value: float = proto.Field(
            proto.DOUBLE,
            number=3,
            oneof="value",
        )
        toggle_value: bool = proto.Field(
            proto.BOOL,
            number=4,
            oneof="value",
        )

    custom_field: str = proto.Field(
        proto.STRING,
        number=1,
    )
    value: Value = proto.Field(
        proto.MESSAGE,
        number=2,
        optional=True,
        message=Value,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "SiteDisapprovalReasonEnum",
        "SiteApprovalStatusEnum",
    },
)


class SiteDisapprovalReasonEnum(proto.Message):
    r"""Wrapper message for
    [SiteDisapprovalReason][google.ads.admanager.v1.SiteDisapprovalReasonEnum.SiteDisapprovalReason]

    """

    class SiteDisapprovalReason(proto.Enum):
        r"""The list of possible policy violation types for a Site.

        Values:
            SITE_DISAPPROVAL_REASON_UNSPECIFIED (0):
                Default value. This value is unused.
            CONTENT (1):
                The site has content that violates policy.
            OTHER (2):
                Generic error type.
            OWNERSHIP (3):
                The parent must be an authorized seller of
                the child network's inventory.
        """
        SITE_DISAPPROVAL_REASON_UNSPECIFIED = 0
        CONTENT = 1
        OTHER = 2
        OWNERSHIP = 3


class SiteApprovalStatusEnum(proto.Message):
    r"""Wrapper message for
    [SiteApprovalStatus][google.ads.admanager.v1.SiteApprovalStatusEnum.SiteApprovalStatus]

    """

    class SiteApprovalStatus(proto.Enum):
        r"""Represents the approval status of a site.

        Values:
            SITE_APPROVAL_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            APPROVED (1):
                The site has been approved to serve ads.
            DISAPPROVED (2):
                The site has been disapproved from serving
                ads.
            DRAFT (3):
                The default status with which a site is
                created.
            REQUIRES_REVIEW (4):
                The site has been deactivated and is not
                serving ads due to dormancy. It must be
                resubmitted for approval.
            UNCHECKED (5):
                Once the site is submitted for approval, its
                status changes from draft to unchecked. It will
                be reviwed with an estimated turn-around time of
                24h. Such a site cannot serve ads.
        """
        SITE_APPROVAL_STATUS_UNSPECIFIED = 0
        APPROVED = 1
        DISAPPROVED = 2
        DRAFT = 3
        REQUIRES_REVIEW = 4
        UNCHECKED = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Network",
    },
)


class Network(proto.Message):
    r"""The Network resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the Network. Format:
            networks/{network_code}
        display_name (str):
            Optional. Display name for Network.

            This field is a member of `oneof`_ ``_display_name``.
        network_code (str):
            Output only. Network Code.

            This field is a member of `oneof`_ ``_network_code``.
        property_code (str):
            Output only. Property code.

            This field is a member of `oneof`_ ``_property_code``.
        time_zone (str):
            Output only. Time zone associated with the
            delivery of orders and reporting.

            This field is a member of `oneof`_ ``_time_zone``.
        currency_code (str):
            Output only. Primary currency code, in
            ISO-4217 format.

            This field is a member of `oneof`_ ``_currency_code``.
        secondary_currency_codes (MutableSequence[str]):
            Optional. Currency codes that can be used as
            an alternative to the primary currency code for
            trafficking Line Items.
        effective_root_ad_unit (str):
            Output only. Top most `Ad
            Unit <google.ads.admanager.v1.AdUnit>`__ to which descendant
            Ad Units can be added. Format:
            networks/{network_code}/adUnits/{ad_unit}

            This field is a member of `oneof`_ ``_effective_root_ad_unit``.
        test_network (bool):
            Output only. Whether this is a test network.

            This field is a member of `oneof`_ ``_test_network``.
        network_id (int):
            Output only. Network ID.

            This field is a member of `oneof`_ ``_network_id``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    network_code: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    property_code: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    time_zone: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    currency_code: str = proto.Field(
        proto.STRING,
        number=6,
        optional=True,
    )
    secondary_currency_codes: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    effective_root_ad_unit: str = proto.Field(
        proto.STRING,
        number=8,
        optional=True,
    )
    test_network: bool = proto.Field(
        proto.BOOL,
        number=10,
        optional=True,
    )
    network_id: int = proto.Field(
        proto.INT64,
        number=11,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "EntitySignalsMapping",
    },
)


class EntitySignalsMapping(proto.Message):
    r"""The ``EntitySignalsMapping`` resource.

    This message has `oneof`_ fields (mutually exclusive fields).
    For each oneof, at most one member field can be set at the same time.
    Setting any member of the oneof automatically clears all other
    members.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        audience_segment_id (int):
            ID of an AudienceSegment that this mapping
            belongs to.

            This field is a member of `oneof`_ ``entity``.
        content_bundle_id (int):
            ID of a ContentBundle that this mapping
            belongs to.

            This field is a member of `oneof`_ ``entity``.
        custom_targeting_value_id (int):
            ID of a CustomValue that this mapping belongs
            to.

            This field is a member of `oneof`_ ``entity``.
        name (str):
            Identifier. The resource name of the
            ``EntitySignalsMapping``. Format:
            ``networks/{network_code}/entitySignalsMappings/{entity_signals_mapping_id}``
        entity_signals_mapping_id (int):
            Output only. ``EntitySignalsMapping`` ID.

            This field is a member of `oneof`_ ``_entity_signals_mapping_id``.
        taxonomy_category_ids (MutableSequence[int]):
            Optional. The IDs of the categories that are
            associated with the referencing entity.
    """

    audience_segment_id: int = proto.Field(
        proto.INT64,
        number=3,
        oneof="entity",
    )
    content_bundle_id: int = proto.Field(
        proto.INT64,
        number=4,
        oneof="entity",
    )
    custom_targeting_value_id: int = proto.Field(
        proto.INT64,
        number=5,
        oneof="entity",
    )
    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    entity_signals_mapping_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    taxonomy_category_ids: MutableSequence[int] = proto.RepeatedField(
        proto.INT64,
        number=6,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import duration_pb2  # type: ignore
from google.protobuf import timestamp_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import early_ad_break_notification_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "AdBreak",
    },
)


class AdBreak(proto.Message):
    r"""The ``AdBreak`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``AdBreak``. This field
            uses the ``LiveStreamEvent`` resource's asset key in the
            URI, even if the ad break was created, updated, or queried
            using the custom asset key.

            Format:
            ``networks/{network_code}/liveStreamEventsByAssetKey/{asset_key}/adBreaks/{ad_break_id}``
        ad_break_id (str):
            Optional. Immutable. ``AdBreak`` ID. Must consist only of
            lowercase letters, digits, and hyphens. Ad break IDs have a
            maximum length of 63 characters. If not set, an ad break ID
            is generated as a UUID string.

            This field is a member of `oneof`_ ``_ad_break_id``.
        asset_key (str):
            Optional. Immutable. The asset key of the
            ``LiveStreamEvent`` that the ad break belongs to. Either an
            asset key or a custom asset key must be provided for
            creation.

            This field is a member of `oneof`_ ``_asset_key``.
        custom_asset_key (str):
            Optional. Immutable. The custom asset key of the
            ``LiveStreamEvent`` that the ad break belongs to. Either an
            asset key or a custom asset key must be provided for
            creation.

            This field is a member of `oneof`_ ``_custom_asset_key``.
        expected_start_time (google.protobuf.timestamp_pb2.Timestamp):
            Optional. The expected start time of the ad
            break. When set, the scheduled ad break will be
            decisioned shortly before the expected start
            time.
            If this field is not set, ad decisioning begins
            immediately. An ad break can be created up to
            six hours before the expected start time.

            This field is a member of `oneof`_ ``_expected_start_time``.
        duration (google.protobuf.duration_pb2.Duration):
            Required. The duration of the ``AdBreak``. An expected
            duration in seconds with up to nine fractional digits,
            ending with ``s``, for example, ``3.5s``. This value will be
            updated to match the actual duration from the manifest or
            pod request after the ad break's state is
            [``COMPLETE``][google.ads.admanager.v1.AdBreakStateEnum.AdBreakState.COMPLETE].

            This field is a member of `oneof`_ ``_duration``.
        break_state (google.ads.admanager_v1.types.AdBreakStateEnum.AdBreakState):
            Output only. The state of the ``AdBreak``.

            This field is a member of `oneof`_ ``_break_state``.
        break_sequence (int):
            Output only. The sequence id of the ``AdBreak``. The unique
            sequence number of the created ad break. This value is only
            set after the ``AdBreak`` starts decisioning indicated by
            the ad break state's being
            [``DECISIONED``][google.ads.admanager.v1.AdBreakStateEnum.AdBreakState.DECISIONED]
            .

            This field is a member of `oneof`_ ``_break_sequence``.
        pod_template_name (str):
            Optional. The pod template name of the ``AdBreak``. This
            field is the required unique name across all pod templates
            in the network, not the display name.

            This field is a member of `oneof`_ ``_pod_template_name``.
        custom_params (str):
            Optional. The key-value pairs to be included on the ad
            requests for this ``AdBreak``. Key-value pairs to include on
            ad requests for this break for custom criteria targeting in
            Google Ad Manager, separated by ``=`` and joined by ``&``.

            Format:"key1=value&key2=value".

            This field is a member of `oneof`_ ``_custom_params``.
        scte_35_cue_out (str):
            Optional. The Base64-encoded SCTE-35 command associated with
            the ``AdBreak``. This field can include the
            ``splice_insert()`` or ``time_signal()`` command.

            **Examples**

            - ``time_signal()``
              ::

                 /DA0AAAAAAAA///wBQb+cr0AUAAeAhxDVUVJSAAAjn/PAAGlmbAICAAAAAAsoKGKNAIAmsnRfg==

            - ``splice_insert()``
              ::

                 /DAvAAAAAAAA///wFAVIAACPf+/+c2nALv4AUsz1AAAAAAAKAAhDVUVJAAABNWLbowo=

            This field is a member of `oneof`_ ``_scte_35_cue_out``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    ad_break_id: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    asset_key: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    custom_asset_key: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    expected_start_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=5,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    duration: duration_pb2.Duration = proto.Field(
        proto.MESSAGE,
        number=6,
        optional=True,
        message=duration_pb2.Duration,
    )
    break_state: early_ad_break_notification_enums.AdBreakStateEnum.AdBreakState = (
        proto.Field(
            proto.ENUM,
            number=7,
            optional=True,
            enum=early_ad_break_notification_enums.AdBreakStateEnum.AdBreakState,
        )
    )
    break_sequence: int = proto.Field(
        proto.INT64,
        number=8,
        optional=True,
    )
    pod_template_name: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )
    custom_params: str = proto.Field(
        proto.STRING,
        number=10,
        optional=True,
    )
    scte_35_cue_out: str = proto.Field(
        proto.STRING,
        number=11,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import field_mask_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import site_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GetSiteRequest",
        "ListSitesRequest",
        "ListSitesResponse",
        "CreateSiteRequest",
        "BatchCreateSitesRequest",
        "BatchCreateSitesResponse",
        "UpdateSiteRequest",
        "BatchUpdateSitesRequest",
        "BatchUpdateSitesResponse",
        "BatchDeactivateSitesRequest",
        "BatchDeactivateSitesResponse",
        "BatchSubmitSitesForApprovalRequest",
        "BatchSubmitSitesForApprovalResponse",
    },
)


class GetSiteRequest(proto.Message):
    r"""Request object for ``GetSite`` method.

    Attributes:
        name (str):
            Required. The resource name of the Site. Format:
            ``networks/{network_code}/sites/{site_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListSitesRequest(proto.Message):
    r"""Request object for ``ListSites`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of Sites.
            Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of ``Sites`` to return. The
            service may return fewer than this value. If unspecified, at
            most 50 ``Sites`` will be returned. The maximum value is
            1000; values greater than 1000 will be coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListSites`` call. Provide this to retrieve the subsequent
            page.

            When paginating, all other parameters provided to
            ``ListSites`` must match the call that provided the page
            token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListSitesResponse(proto.Message):
    r"""Response object for ``ListSitesRequest`` containing matching
    ``Site`` objects.

    Attributes:
        sites (MutableSequence[google.ads.admanager_v1.types.Site]):
            The ``Site`` objects from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of ``Site`` objects. If a filter was included
            in the request, this reflects the total number after the
            filtering is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    sites: MutableSequence[site_messages.Site] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=site_messages.Site,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


class CreateSiteRequest(proto.Message):
    r"""Request object for ``CreateSite`` method.

    Attributes:
        parent (str):
            Required. The parent resource where this ``Site`` will be
            created. Format: ``networks/{network_code}``
        site (google.ads.admanager_v1.types.Site):
            Required. The ``Site`` to create.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    site: site_messages.Site = proto.Field(
        proto.MESSAGE,
        number=2,
        message=site_messages.Site,
    )


class BatchCreateSitesRequest(proto.Message):
    r"""Request object for ``BatchCreateSites`` method.

    Attributes:
        parent (str):
            Required. The parent resource where ``Sites`` will be
            created. Format: ``networks/{network_code}`` The parent
            field in the CreateSiteRequest must match this field.
        requests (MutableSequence[google.ads.admanager_v1.types.CreateSiteRequest]):
            Required. The ``Site`` objects to create. A maximum of 100
            objects can be created in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["CreateSiteRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="CreateSiteRequest",
    )


class BatchCreateSitesResponse(proto.Message):
    r"""Response object for ``BatchCreateSites`` method.

    Attributes:
        sites (MutableSequence[google.ads.admanager_v1.types.Site]):
            The ``Site`` objects created.
    """

    sites: MutableSequence[site_messages.Site] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=site_messages.Site,
    )


class UpdateSiteRequest(proto.Message):
    r"""Request object for ``UpdateSite`` method.

    Attributes:
        site (google.ads.admanager_v1.types.Site):
            Required. The ``Site`` to update.

            The ``Site``'s ``name`` is used to identify the ``Site`` to
            update.
        update_mask (google.protobuf.field_mask_pb2.FieldMask):
            Required. The list of fields to update.
    """

    site: site_messages.Site = proto.Field(
        proto.MESSAGE,
        number=1,
        message=site_messages.Site,
    )
    update_mask: field_mask_pb2.FieldMask = proto.Field(
        proto.MESSAGE,
        number=2,
        message=field_mask_pb2.FieldMask,
    )


class BatchUpdateSitesRequest(proto.Message):
    r"""Request object for ``BatchUpdateSites`` method.

    Attributes:
        parent (str):
            Required. The parent resource where ``Sites`` will be
            updated. Format: ``networks/{network_code}`` The parent
            field in the UpdateSiteRequest must match this field.
        requests (MutableSequence[google.ads.admanager_v1.types.UpdateSiteRequest]):
            Required. The ``Site`` objects to update. A maximum of 100
            objects can be updated in a batch.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    requests: MutableSequence["UpdateSiteRequest"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="UpdateSiteRequest",
    )


class BatchUpdateSitesResponse(proto.Message):
    r"""Response object for ``BatchUpdateSites`` method.

    Attributes:
        sites (MutableSequence[google.ads.admanager_v1.types.Site]):
            The ``Site`` objects updated.
    """

    sites: MutableSequence[site_messages.Site] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=site_messages.Site,
    )


class BatchDeactivateSitesRequest(proto.Message):
    r"""Request message for ``BatchDeactivateSites`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The resource names of the ``Site`` objects to
            deactivate.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchDeactivateSitesResponse(proto.Message):
    r"""Response object for ``BatchDeactivateSites`` method."""


class BatchSubmitSitesForApprovalRequest(proto.Message):
    r"""Request message for ``BatchSubmitSitesForApproval`` method.

    Attributes:
        parent (str):
            Required. Format: ``networks/{network_code}``
        names (MutableSequence[str]):
            Required. The resource names of the ``Site`` objects to
            submit for approval.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    names: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class BatchSubmitSitesForApprovalResponse(proto.Message):
    r"""Response object for ``BatchSubmitSitesForApproval`` method."""


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "User",
    },
)


class User(proto.Message):
    r"""The User resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the User. Format:
            ``networks/{network_code}/users/{user_id}``
        user_id (int):
            Output only. ``User`` ID.

            This field is a member of `oneof`_ ``_user_id``.
        display_name (str):
            Required. The name of the User. It has a
            maximum length of 128 characters.

            This field is a member of `oneof`_ ``_display_name``.
        email (str):
            Required. The email or login of the User. In
            order to create a new user, you must already
            have a Google Account.

            This field is a member of `oneof`_ ``_email``.
        role (str):
            Required. The unique Role ID of the User.
            Roles that are created by Google will have
            negative IDs.

            This field is a member of `oneof`_ ``_role``.
        active (bool):
            Output only. Specifies whether or not the
            User is active. An inactive user cannot log in
            to the system or perform any operations.

            This field is a member of `oneof`_ ``_active``.
        external_id (str):
            Optional. An identifier for the User that is
            meaningful to the publisher. This attribute has
            a maximum length of 255 characters.

            This field is a member of `oneof`_ ``_external_id``.
        service_account (bool):
            Output only. Whether the user is an OAuth2
            service account user. Service account users can
            only be added through the UI.

            This field is a member of `oneof`_ ``_service_account``.
        orders_ui_local_time_zone (str):
            Optional. The IANA Time Zone Database time zone, e.g.
            "America/New_York", used in the orders and line items UI for
            this User. If not provided, the UI then defaults to using
            the Network's timezone. This setting only affects the UI for
            this user and does not affect the timezone of any dates and
            times returned in API responses.

            This field is a member of `oneof`_ ``_orders_ui_local_time_zone``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    user_id: int = proto.Field(
        proto.INT64,
        number=10,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
        optional=True,
    )
    email: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    role: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    active: bool = proto.Field(
        proto.BOOL,
        number=6,
        optional=True,
    )
    external_id: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    service_account: bool = proto.Field(
        proto.BOOL,
        number=8,
        optional=True,
    )
    orders_ui_local_time_zone: str = proto.Field(
        proto.STRING,
        number=9,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "ProgrammaticBuyer",
    },
)


class ProgrammaticBuyer(proto.Message):
    r"""Represents a programmatic buyer.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``ProgrammaticBuyer``.
            Format:
            ``networks/{network_code}/programmaticBuyers/{buyer_account_id}``
        buyer_account_id (int):
            Output only. The buyer account ID of the
            buyer.

            This field is a member of `oneof`_ ``_buyer_account_id``.
        display_name (str):
            Output only. The display name of the buyer.

            This field is a member of `oneof`_ ``_display_name``.
        parent_account_id (int):
            Output only. The ID of the programmatic
            buyer's sponsor. If the buyer has no sponsor,
            this field will be -1.

            This field is a member of `oneof`_ ``_parent_account_id``.
        partner_client_id (str):
            Output only. ID of the Display & Video 360
            client buyer partner ID (if Display & Video 360)
            or Authorized Buyers client buyer account ID.

            This field is a member of `oneof`_ ``_partner_client_id``.
        agency (bool):
            Output only. Whether the buyer is an
            advertising agency.

            This field is a member of `oneof`_ ``_agency``.
        preferred_deals_enabled (bool):
            Output only. Whether the buyer is enabled for
            preferred deals.

            This field is a member of `oneof`_ ``_preferred_deals_enabled``.
        programmatic_guaranteed_enabled (bool):
            Output only. Whether the buyer is enabled for
            programmatic guaranteed deals.

            This field is a member of `oneof`_ ``_programmatic_guaranteed_enabled``.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    buyer_account_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=5,
        optional=True,
    )
    parent_account_id: int = proto.Field(
        proto.INT64,
        number=6,
        optional=True,
    )
    partner_client_id: str = proto.Field(
        proto.STRING,
        number=7,
        optional=True,
    )
    agency: bool = proto.Field(
        proto.BOOL,
        number=9,
        optional=True,
    )
    preferred_deals_enabled: bool = proto.Field(
        proto.BOOL,
        number=12,
        optional=True,
    )
    programmatic_guaranteed_enabled: bool = proto.Field(
        proto.BOOL,
        number=13,
        optional=True,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import custom_field_enums

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CustomField",
        "CustomFieldOption",
    },
)


class CustomField(proto.Message):
    r"""An additional, user-created field on an entity.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``CustomField``.
            Format:
            ``networks/{network_code}/customFields/{custom_field}``
        custom_field_id (int):
            Output only. Unique ID of the CustomField.
            This attribute is assigned by Google.

            This field is a member of `oneof`_ ``_custom_field_id``.
        display_name (str):
            Required. Name of the CustomField. The max
            length is 127 characters.

            This field is a member of `oneof`_ ``_display_name``.
        description (str):
            Optional. A description of the custom field.
            The maximum length is 511 characters.

            This field is a member of `oneof`_ ``_description``.
        status (google.ads.admanager_v1.types.CustomFieldStatusEnum.CustomFieldStatus):
            Output only. The status of the ``CustomField``.

            This field is a member of `oneof`_ ``_status``.
        entity_type (google.ads.admanager_v1.types.CustomFieldEntityTypeEnum.CustomFieldEntityType):
            Required. The type of entity the ``CustomField`` can be
            applied to.

            This field is a member of `oneof`_ ``_entity_type``.
        data_type (google.ads.admanager_v1.types.CustomFieldDataTypeEnum.CustomFieldDataType):
            Required. The data type of the ``CustomField``.

            This field is a member of `oneof`_ ``_data_type``.
        visibility (google.ads.admanager_v1.types.CustomFieldVisibilityEnum.CustomFieldVisibility):
            Required. The visibility of the ``CustomField``.

            This field is a member of `oneof`_ ``_visibility``.
        options (MutableSequence[google.ads.admanager_v1.types.CustomFieldOption]):
            Optional. The drop-down options for the ``CustomField``.

            Only applicable for ``CustomField`` with the drop-down data
            type.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    custom_field_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )
    description: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    status: custom_field_enums.CustomFieldStatusEnum.CustomFieldStatus = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=custom_field_enums.CustomFieldStatusEnum.CustomFieldStatus,
    )
    entity_type: custom_field_enums.CustomFieldEntityTypeEnum.CustomFieldEntityType = (
        proto.Field(
            proto.ENUM,
            number=7,
            optional=True,
            enum=custom_field_enums.CustomFieldEntityTypeEnum.CustomFieldEntityType,
        )
    )
    data_type: custom_field_enums.CustomFieldDataTypeEnum.CustomFieldDataType = (
        proto.Field(
            proto.ENUM,
            number=8,
            optional=True,
            enum=custom_field_enums.CustomFieldDataTypeEnum.CustomFieldDataType,
        )
    )
    visibility: custom_field_enums.CustomFieldVisibilityEnum.CustomFieldVisibility = (
        proto.Field(
            proto.ENUM,
            number=9,
            optional=True,
            enum=custom_field_enums.CustomFieldVisibilityEnum.CustomFieldVisibility,
        )
    )
    options: MutableSequence["CustomFieldOption"] = proto.RepeatedField(
        proto.MESSAGE,
        number=10,
        message="CustomFieldOption",
    )


class CustomFieldOption(proto.Message):
    r"""An option for a drop-down ``CustomField``.

    Attributes:
        custom_field_option_id (int):
            Optional. Non-empty default. ``CustomFieldOption`` ID.
        display_name (str):
            Required. The display name of the ``CustomFieldOption``.

            This value has a maximum length of 127 characters.
    """

    custom_field_option_id: int = proto.Field(
        proto.INT64,
        number=1,
    )
    display_name: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import (
    request_platform_enum,
    targeted_video_bumper_type_enum,
    video_position_enum,
)

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "Targeting",
        "GeoTargeting",
        "TechnologyTargeting",
        "BandwidthTargeting",
        "BrowserTargeting",
        "BrowserLanguageTargeting",
        "DeviceCategoryTargeting",
        "DeviceCapabilityTargeting",
        "DeviceManufacturerTargeting",
        "MobileCarrierTargeting",
        "OperatingSystemTargeting",
        "InventoryTargeting",
        "AdUnitTargeting",
        "RequestPlatformTargeting",
        "CustomTargeting",
        "CustomTargetingClause",
        "CustomTargetingLiteral",
        "AudienceSegmentTargeting",
        "CmsMetadataTargeting",
        "UserDomainTargeting",
        "VideoPositionTargeting",
        "VideoPosition",
        "DataSegmentTargeting",
        "ContentTargeting",
        "MobileApplicationTargeting",
        "FirstPartyMobileApplicationTargeting",
    },
)


class Targeting(proto.Message):
    r"""Targeting expression.

    Attributes:
        geo_targeting (google.ads.admanager_v1.types.GeoTargeting):
            Optional. Used to target/exclude various geo
            targets.
        technology_targeting (google.ads.admanager_v1.types.TechnologyTargeting):
            Optional. Used to target various technology
            targeting dimensions.
        inventory_targeting (google.ads.admanager_v1.types.InventoryTargeting):
            Optional. Used to target/exclude various ad
            units and/or placements.
        request_platform_targeting (google.ads.admanager_v1.types.RequestPlatformTargeting):
            Optional. Used to target specific request
            platforms.
        custom_targeting (google.ads.admanager_v1.types.CustomTargeting):
            Optional. Used to target key/values, audience
            segments, and/or CMS metadata.
        user_domain_targeting (google.ads.admanager_v1.types.UserDomainTargeting):
            Optional. Used to target user domains.
        video_position_targeting (google.ads.admanager_v1.types.VideoPositionTargeting):
            Optional. Used to target video positions.
        data_segment_targeting (google.ads.admanager_v1.types.DataSegmentTargeting):
            Optional. Used to target data segments.
        content_targeting (google.ads.admanager_v1.types.ContentTargeting):
            Optional. Used to target content.
        mobile_application_targeting (google.ads.admanager_v1.types.MobileApplicationTargeting):
            Optional. Used to target mobile applications.
    """

    geo_targeting: "GeoTargeting" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="GeoTargeting",
    )
    technology_targeting: "TechnologyTargeting" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="TechnologyTargeting",
    )
    inventory_targeting: "InventoryTargeting" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="InventoryTargeting",
    )
    request_platform_targeting: "RequestPlatformTargeting" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="RequestPlatformTargeting",
    )
    custom_targeting: "CustomTargeting" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="CustomTargeting",
    )
    user_domain_targeting: "UserDomainTargeting" = proto.Field(
        proto.MESSAGE,
        number=10,
        message="UserDomainTargeting",
    )
    video_position_targeting: "VideoPositionTargeting" = proto.Field(
        proto.MESSAGE,
        number=12,
        message="VideoPositionTargeting",
    )
    data_segment_targeting: "DataSegmentTargeting" = proto.Field(
        proto.MESSAGE,
        number=13,
        message="DataSegmentTargeting",
    )
    content_targeting: "ContentTargeting" = proto.Field(
        proto.MESSAGE,
        number=15,
        message="ContentTargeting",
    )
    mobile_application_targeting: "MobileApplicationTargeting" = proto.Field(
        proto.MESSAGE,
        number=18,
        message="MobileApplicationTargeting",
    )


class GeoTargeting(proto.Message):
    r"""Represents a list of targeted and excluded geos.

    Attributes:
        targeted_geos (MutableSequence[str]):
            Optional. A list of geo resource names that
            should be targeted/included.
        excluded_geos (MutableSequence[str]):
            Optional. A list of geo resource names that
            should be excluded.
    """

    targeted_geos: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_geos: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class TechnologyTargeting(proto.Message):
    r"""Various types of technology targeting expressed by child
    messages are applied with logical AND.

    Attributes:
        bandwidth_targeting (google.ads.admanager_v1.types.BandwidthTargeting):
            Optional. Bandwidth targeting dimension.
        browser_targeting (google.ads.admanager_v1.types.BrowserTargeting):
            Optional. Browser targeting dimension.
        browser_language_targeting (google.ads.admanager_v1.types.BrowserLanguageTargeting):
            Optional. Browser language targeting
            dimension.
        device_capability_targeting (google.ads.admanager_v1.types.DeviceCapabilityTargeting):
            Optional. Device capability targeting
            dimension.
        device_category_targeting (google.ads.admanager_v1.types.DeviceCategoryTargeting):
            Optional. Device category targeting
            dimension.
        device_manufacturer_targeting (google.ads.admanager_v1.types.DeviceManufacturerTargeting):
            Optional. Device manufacturer targeting
            dimension.
        mobile_carrier_targeting (google.ads.admanager_v1.types.MobileCarrierTargeting):
            Optional. Mobile carrier targeting dimension.
        operating_system_targeting (google.ads.admanager_v1.types.OperatingSystemTargeting):
            Optional. Operating system targeting
            dimension.
    """

    bandwidth_targeting: "BandwidthTargeting" = proto.Field(
        proto.MESSAGE,
        number=3,
        message="BandwidthTargeting",
    )
    browser_targeting: "BrowserTargeting" = proto.Field(
        proto.MESSAGE,
        number=4,
        message="BrowserTargeting",
    )
    browser_language_targeting: "BrowserLanguageTargeting" = proto.Field(
        proto.MESSAGE,
        number=5,
        message="BrowserLanguageTargeting",
    )
    device_capability_targeting: "DeviceCapabilityTargeting" = proto.Field(
        proto.MESSAGE,
        number=6,
        message="DeviceCapabilityTargeting",
    )
    device_category_targeting: "DeviceCategoryTargeting" = proto.Field(
        proto.MESSAGE,
        number=1,
        message="DeviceCategoryTargeting",
    )
    device_manufacturer_targeting: "DeviceManufacturerTargeting" = proto.Field(
        proto.MESSAGE,
        number=7,
        message="DeviceManufacturerTargeting",
    )
    mobile_carrier_targeting: "MobileCarrierTargeting" = proto.Field(
        proto.MESSAGE,
        number=8,
        message="MobileCarrierTargeting",
    )
    operating_system_targeting: "OperatingSystemTargeting" = proto.Field(
        proto.MESSAGE,
        number=2,
        message="OperatingSystemTargeting",
    )


class BandwidthTargeting(proto.Message):
    r"""Bandwidth Targeting.

    Reach users accessing the internet via various means of
    connection, such as cable, DSL, or dial-up. Can be useful to
    target campaigns using low-resolution creatives or text ads for
    users with low bandwidth.

    Attributes:
        targeted_bandwidth_groups (MutableSequence[str]):
            Optional. A list of resource names of the
            bandwidth groups that should be
            targeted/included.
        excluded_bandwidth_groups (MutableSequence[str]):
            Optional. A list of resource names of the
            bandwidth groups that should be excluded.
    """

    targeted_bandwidth_groups: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_bandwidth_groups: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class BrowserTargeting(proto.Message):
    r"""Browser Targeting.

    Allows publishers to target/exclude a browser type (e.g. Chrome,
    Firefox, Safari). For more information, see
    https://support.google.com/admanager/answer/2884033 (Targeting
    types > Browser).

    Attributes:
        targeted_browsers (MutableSequence[str]):
            Optional. A list of browser resource names
            that should be targeted/included.
        excluded_browsers (MutableSequence[str]):
            Optional. A list of browser resource names
            that should be excluded.
    """

    targeted_browsers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_browsers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class BrowserLanguageTargeting(proto.Message):
    r"""Browser Language Targeting.

    For ads targeting mobile apps and their associated WebViews, the
    language used is based on the language specified by the user in
    their mobile device settings. If a browser has more than one
    language assigned to it, each language generates an impression.

    Attributes:
        targeted_browser_languages (MutableSequence[str]):
            Optional. A list of browser language resource
            names that should be targeted/included.
        excluded_browser_languages (MutableSequence[str]):
            Optional. A list of browser language resource
            names that should be excluded.
    """

    targeted_browser_languages: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_browser_languages: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class DeviceCategoryTargeting(proto.Message):
    r"""Represents a list of targeted and excluded device categories.

    Attributes:
        targeted_categories (MutableSequence[str]):
            Optional. A list of device category resource
            names that should be targeted/included.
        excluded_categories (MutableSequence[str]):
            Optional. A list of device category resource
            names that should be excluded.
    """

    targeted_categories: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_categories: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class DeviceCapabilityTargeting(proto.Message):
    r"""Device Capability Targeting.

    Can be used to target/exclude users using mobile apps, ad
    requests resulting from apps built on the MRAID standard, or
    users on devices that are able to make phone calls versus
    devices that aren't able to make phone calls, such as tablets.

    Attributes:
        targeted_capabilities (MutableSequence[str]):
            Optional. A list of device capability
            resource names that should be targeted/included.
        excluded_capabilities (MutableSequence[str]):
            Optional. A list of device capability
            resource names that should be excluded.
    """

    targeted_capabilities: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_capabilities: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class DeviceManufacturerTargeting(proto.Message):
    r"""Device Manufacturer Targeting.

    Can be used to target/exclude users on devices made by specific
    brands or companies, such as Apple, Google, Samsung and others.
    For more information, see
    https://support.google.com/admanager/answer/2884033 ("Targeting
    types > Device manufacturer").

    Attributes:
        targeted_device_manufacturers (MutableSequence[str]):
            Optional. A list of device manufacturer
            resource names that should be targeted/included.
        excluded_device_manufacturers (MutableSequence[str]):
            Optional. A list of device manufacturer
            resource names that should be excluded.
        targeted_mobile_devices (MutableSequence[str]):
            Optional. A list of mobile device resource
            names that should be targeted/included.
        excluded_mobile_devices (MutableSequence[str]):
            Optional. A list of mobile device resource
            names that should be excluded.
        targeted_mobile_device_submodels (MutableSequence[str]):
            Optional. A list of mobile device submodel
            resource names that should be targeted/included.
        excluded_mobile_device_submodels (MutableSequence[str]):
            Optional. A list of mobile device submodel
            resource names that should be excluded.
    """

    targeted_device_manufacturers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    excluded_device_manufacturers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )
    targeted_mobile_devices: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=9,
    )
    excluded_mobile_devices: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=10,
    )
    targeted_mobile_device_submodels: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=11,
    )
    excluded_mobile_device_submodels: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=12,
    )


class MobileCarrierTargeting(proto.Message):
    r"""Mobile Carrier Targeting.

    Can be used to target/exclude a variety of mobile carriers, such
    as AT&T, Verizon, or T-Mobile.

    Attributes:
        targeted_mobile_carriers (MutableSequence[str]):
            Optional. A list of mobile carrier resource
            names that should be targeted/included.
        excluded_mobile_carriers (MutableSequence[str]):
            Optional. A list of mobile carrier resource
            names that should be excluded.
    """

    targeted_mobile_carriers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_mobile_carriers: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


class OperatingSystemTargeting(proto.Message):
    r"""Operating System Targeting

    Attributes:
        targeted_operating_systems (MutableSequence[str]):
            Optional. A list of operating system resource
            names that should be targeted/included.
        excluded_operating_systems (MutableSequence[str]):
            Optional. A list of operating system resource
            names that should be excluded.
        targeted_operating_system_versions (MutableSequence[str]):
            Optional. A list of operating system version
            resource names that should be targeted/included.
        excluded_operating_system_versions (MutableSequence[str]):
            Optional. A list of operating system version
            resource names that should be excluded.
    """

    targeted_operating_systems: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    excluded_operating_systems: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    targeted_operating_system_versions: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    excluded_operating_system_versions: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )


class InventoryTargeting(proto.Message):
    r"""Targeted ad units and AU placements are applied with logical OR.
    Example:

    (au:1 OR au:2 OR au_placement:5) AND (NOT (au:3))

    Attributes:
        targeted_ad_units (MutableSequence[google.ads.admanager_v1.types.AdUnitTargeting]):
            Optional. A list of ad units that should be
            targeted/included.
        excluded_ad_units (MutableSequence[google.ads.admanager_v1.types.AdUnitTargeting]):
            Optional. A list of ad units that should be
            excluded.
            Excluded AUs take precedence over targeted AUs.
            In fact an AU can be excluded only if one of its
            ancestors is targeted. Subsequently child AUs of
            an excluded AU can not be targeted (except via a
            placement).
        targeted_placements (MutableSequence[str]):
            Optional. The resource names of the
            placements that should be targeted/included.
    """

    targeted_ad_units: MutableSequence["AdUnitTargeting"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="AdUnitTargeting",
    )
    excluded_ad_units: MutableSequence["AdUnitTargeting"] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="AdUnitTargeting",
    )
    targeted_placements: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


class AdUnitTargeting(proto.Message):
    r"""Specifies an ad unit and (optionally) its descendants.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        include_descendants (bool):
            Whether this ad unit's children should be
            targeted/excluded as well.

            This field is a member of `oneof`_ ``_include_descendants``.
        ad_unit (str):
            Optional. The resource name of this ad unit.

            This field is a member of `oneof`_ ``_ad_unit``.
    """

    include_descendants: bool = proto.Field(
        proto.BOOL,
        number=1,
        optional=True,
    )
    ad_unit: str = proto.Field(
        proto.STRING,
        number=3,
        optional=True,
    )


class RequestPlatformTargeting(proto.Message):
    r"""Represents a list of targeted request platforms.

    Attributes:
        request_platforms (MutableSequence[google.ads.admanager_v1.types.RequestPlatformEnum.RequestPlatform]):
            Optional. The list of request platforms that
            should be targeted.
    """

    request_platforms: MutableSequence[
        request_platform_enum.RequestPlatformEnum.RequestPlatform
    ] = proto.RepeatedField(
        proto.ENUM,
        number=1,
        enum=request_platform_enum.RequestPlatformEnum.RequestPlatform,
    )


class CustomTargeting(proto.Message):
    r"""Represents the top level targeting expression for custom
    key/values, audience segments, and/or CMS metadata.

    Attributes:
        custom_targeting_clauses (MutableSequence[google.ads.admanager_v1.types.CustomTargetingClause]):
            Optional. These clauses are all ORed
            together.
    """

    custom_targeting_clauses: MutableSequence[
        "CustomTargetingClause"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="CustomTargetingClause",
    )


class CustomTargetingClause(proto.Message):
    r"""Represents a logical AND of individual custom targeting
    expressions.

    Attributes:
        custom_targeting_literals (MutableSequence[google.ads.admanager_v1.types.CustomTargetingLiteral]):
            Optional. Leaf targeting expressions for
            custom key/values.
        audience_segment_targetings (MutableSequence[google.ads.admanager_v1.types.AudienceSegmentTargeting]):
            Optional. Leaf targeting expressions for
            audience segments.
        cms_metadata_targetings (MutableSequence[google.ads.admanager_v1.types.CmsMetadataTargeting]):
            Optional. Leaf targeting expressions for cms
            metadata.
    """

    custom_targeting_literals: MutableSequence[
        "CustomTargetingLiteral"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="CustomTargetingLiteral",
    )
    audience_segment_targetings: MutableSequence[
        "AudienceSegmentTargeting"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=2,
        message="AudienceSegmentTargeting",
    )
    cms_metadata_targetings: MutableSequence[
        "CmsMetadataTargeting"
    ] = proto.RepeatedField(
        proto.MESSAGE,
        number=3,
        message="CmsMetadataTargeting",
    )


class CustomTargetingLiteral(proto.Message):
    r"""Represents targeting for custom key/values. The values are
    ORed together.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        negative (bool):
            Whether this expression is negatively
            targeted, meaning it matches ad requests that
            exclude the below values.

            This field is a member of `oneof`_ ``_negative``.
        custom_targeting_key (str):
            Optional. The resource name of the targeted
            CustomKey.

            This field is a member of `oneof`_ ``_custom_targeting_key``.
        custom_targeting_values (MutableSequence[str]):
            Optional. The resource names of the targeted
            CustomValues.
    """

    negative: bool = proto.Field(
        proto.BOOL,
        number=1,
        optional=True,
    )
    custom_targeting_key: str = proto.Field(
        proto.STRING,
        number=4,
        optional=True,
    )
    custom_targeting_values: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )


class AudienceSegmentTargeting(proto.Message):
    r"""Represents targeting for audience segments. The values are combined
    in a logical ``OR``.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        negative (bool):
            Whether this expression is negatively
            targeted, meaning it matches ad requests that
            exclude the below values.

            This field is a member of `oneof`_ ``_negative``.
        audience_segments (MutableSequence[str]):
            Optional. The targeted audience segments.

            This is either the resource name of a first-party audience
            segment or an alias to the effective third-party audience
            segment. Third-party audience segment resource names
            containing ``~direct`` or ``~global`` will be normalized by
            the server. For example,
            ``networks/1234/audienceSegments/4567~direct`` will be
            normalized to ``networks/1234/audienceSegments/4567``.
    """

    negative: bool = proto.Field(
        proto.BOOL,
        number=1,
        optional=True,
    )
    audience_segments: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class CmsMetadataTargeting(proto.Message):
    r"""Represents targeting for CMS metadata. The values are ORed
    together.


    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        negative (bool):
            Whether this expression is negatively
            targeted, meaning it matches ad requests that
            exclude the below values.

            This field is a member of `oneof`_ ``_negative``.
        cms_metadata_values (MutableSequence[str]):
            Optional. The resource names of the targeted
            CMS metadata values.
    """

    negative: bool = proto.Field(
        proto.BOOL,
        number=1,
        optional=True,
    )
    cms_metadata_values: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )


class UserDomainTargeting(proto.Message):
    r"""User Domain Targeting

    Attributes:
        targeted_user_domains (MutableSequence[str]):
            Optional. A list of user domains that should
            be targeted/included.
        excluded_user_domains (MutableSequence[str]):
            Optional. A list of user domains that should
            be excluded.
    """

    targeted_user_domains: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=1,
    )
    excluded_user_domains: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=2,
    )


class VideoPositionTargeting(proto.Message):
    r"""Video Position Targeting

    Attributes:
        video_positions (MutableSequence[google.ads.admanager_v1.types.VideoPosition]):
            Optional. A list of video position targeting
            criterion (applied with a logical AND).
    """

    video_positions: MutableSequence["VideoPosition"] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message="VideoPosition",
    )


class VideoPosition(proto.Message):
    r"""Video Position Targeting Criterion

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        midroll_index (int):
            Optional. The index of the mid-roll to target. This field is
            ignored when targeting any video position (e.g.
            position_type) other than MIDROLL.

            This field is a member of `oneof`_ ``_midroll_index``.
        reverse_midroll_index (int):
            Optional. The index from the back of the pod of the mid-roll
            to target. This field is ignored when targeting any video
            position (e.g. position_type) other than MIDROLL or if
            targeting a specific midroll index (e.g. midroll_index !=
            0).

            This field is a member of `oneof`_ ``_reverse_midroll_index``.
        pod_position (int):
            Optional. The video position within a pod to target. This
            field must be unset in order to target a specific video
            position (e.g. position_type), bumper type (e.g.
            bumper_type), or custom ad spot (e.g. custom_spot_id).

            This field is a member of `oneof`_ ``_pod_position``.
        position_type (google.ads.admanager_v1.types.VideoPositionEnum.VideoPosition):
            Optional. The position within a video to
            target. A video ad can target a position
            (pre-roll, all mid-rolls, or post-roll) or a
            specific mid-roll index.

            This field is a member of `oneof`_ ``_position_type``.
        bumper_type (google.ads.admanager_v1.types.TargetedVideoBumperTypeEnum.TargetedVideoBumperType):
            Optional. The video bumper type to target. This field must
            be unset in order to target a specific video position (e.g.
            position_type), pod position (e.g. pod_position), or custom
            ad spot (e.g. custom_spot_id).

            This field is a member of `oneof`_ ``_bumper_type``.
    """

    midroll_index: int = proto.Field(
        proto.INT64,
        number=1,
        optional=True,
    )
    reverse_midroll_index: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    pod_position: int = proto.Field(
        proto.INT64,
        number=3,
        optional=True,
    )
    position_type: video_position_enum.VideoPositionEnum.VideoPosition = proto.Field(
        proto.ENUM,
        number=5,
        optional=True,
        enum=video_position_enum.VideoPositionEnum.VideoPosition,
    )
    bumper_type: targeted_video_bumper_type_enum.TargetedVideoBumperTypeEnum.TargetedVideoBumperType = proto.Field(
        proto.ENUM,
        number=6,
        optional=True,
        enum=targeted_video_bumper_type_enum.TargetedVideoBumperTypeEnum.TargetedVideoBumperType,
    )


class DataSegmentTargeting(proto.Message):
    r"""Data Segment Targeting

    Attributes:
        has_data_segment_targeting (bool):
            Output only. Whether any data segments are
            currently targeted.
    """

    has_data_segment_targeting: bool = proto.Field(
        proto.BOOL,
        number=2,
    )


class ContentTargeting(proto.Message):
    r"""Content Targeting

    Targeted/excluded content entities and bundles.

    Attributes:
        targeted_content (MutableSequence[str]):
            Optional. The resource names of the
            [Content][google.ads.admanager.v1.Content] that should be
            targeted/included.
        excluded_content (MutableSequence[str]):
            Optional. The resource names of the
            [Content][google.ads.admanager.v1.Content] that should be
            excluded.
        targeted_content_bundles (MutableSequence[str]):
            Optional. The resource names of the
            [ContentBundles][google.ads.admanager.v1.ContentBundle] that
            should be targeted/included.
        excluded_content_bundles (MutableSequence[str]):
            Optional. The resource names of the
            [ContentBundles][google.ads.admanager.v1.ContentBundle] that
            should be excluded.
    """

    targeted_content: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=5,
    )
    excluded_content: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=6,
    )
    targeted_content_bundles: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=7,
    )
    excluded_content_bundles: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=8,
    )


class MobileApplicationTargeting(proto.Message):
    r"""Mobile Application Targeting

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        first_party_targeting (google.ads.admanager_v1.types.FirstPartyMobileApplicationTargeting):
            Optional. The targeted/excluded first-party
            mobile applications.

            This field is a member of `oneof`_ ``targeting``.
    """

    first_party_targeting: "FirstPartyMobileApplicationTargeting" = proto.Field(
        proto.MESSAGE,
        number=1,
        oneof="targeting",
        message="FirstPartyMobileApplicationTargeting",
    )


class FirstPartyMobileApplicationTargeting(proto.Message):
    r"""First-party mobile application targeting.

    Attributes:
        targeted_applications (MutableSequence[str]):
            Optional. The resource names of the
            first-party applications that should be
            targeted.
        excluded_applications (MutableSequence[str]):
            Optional. The resource names of the
            first-party applications that should be
            excluded.
    """

    targeted_applications: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=3,
    )
    excluded_applications: MutableSequence[str] = proto.RepeatedField(
        proto.STRING,
        number=4,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "TeamStatusEnum",
        "TeamAccessTypeEnum",
    },
)


class TeamStatusEnum(proto.Message):
    r"""Wrapper message for
    [TeamStatus][google.ads.admanager.v1.TeamStatusEnum.TeamStatus]

    """

    class TeamStatus(proto.Enum):
        r"""Represents the status of a team, whether it is active or
        inactive.

        Values:
            TEAM_STATUS_UNSPECIFIED (0):
                Default value. This value is unused.
            ACTIVE (1):
                The status of an active team.
            INACTIVE (2):
                The status of an inactive team.
        """
        TEAM_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2


class TeamAccessTypeEnum(proto.Message):
    r"""Wrapper message for
    [TeamAccessType][google.ads.admanager.v1.TeamAccessTypeEnum.TeamAccessType]

    """

    class TeamAccessType(proto.Enum):
        r"""Represents the types of team access supported for orders.

        Values:
            TEAM_ACCESS_TYPE_UNSPECIFIED (0):
                Default value. This value is unused.
            NONE (1):
                The level of access in which team members
                can't view or edit a team's orders.
            READ_ONLY (2):
                The level of access in which team members can
                only view a team's orders.
            READ_WRITE (3):
                The level of access in which team members can
                view and edit a team's orders.
        """
        TEAM_ACCESS_TYPE_UNSPECIFIED = 0
        NONE = 1
        READ_ONLY = 2
        READ_WRITE = 3


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "RequestPlatformEnum",
    },
)


class RequestPlatformEnum(proto.Message):
    r"""Wrapper message for [RequestPlatform].

    Describes the platform from which a request is made and on which the
    ad is rendered. In the event of multiple platforms, the platform
    that ultimately renders the ad is the targeted platform. For
    example, a video player on a website would have a request platform
    of ``VIDEO_PLAYER``.

    """

    class RequestPlatform(proto.Enum):
        r"""The different environments in which an ad can be shown.

        Values:
            REQUEST_PLATFORM_UNSPECIFIED (0):
                No value specified
            BROWSER (1):
                Represents a request made from a web browser
                (incl. desktop browsers, mobile browsers,
                webviews, etc.).
            MOBILE_APP (2):
                Represents a request made from a Mobile
                Application.
            VIDEO_PLAYER (3):
                Represents a request made from a video
                player.
        """
        REQUEST_PLATFORM_UNSPECIFIED = 0
        BROWSER = 1
        MOBILE_APP = 2
        VIDEO_PLAYER = 3


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "CompanyTypeEnum",
        "CompanyCreditStatusEnum",
    },
)


class CompanyTypeEnum(proto.Message):
    r"""Wrapper message for
    [CompanyType][google.ads.admanager.v1.CompanyTypeEnum.CompanyType]

    """

    class CompanyType(proto.Enum):
        r"""The type of a company.

        Values:
            COMPANY_TYPE_UNSPECIFIED (0):
                No value specified
            ADVERTISER (1):
                A business entity that purchases ad
                inventory.
            HOUSE_ADVERTISER (2):
                A company representing the publisher's own
                advertiser for house ads.
            AGENCY (3):
                An organization that manages ad accounts and
                offers services, such as ad creation, placement,
                and management to advertisers.
            HOUSE_AGENCY (4):
                A company representing the publisher's own
                agency.
            AD_NETWORK (5):
                A company representing multiple advertisers
                and agencies.
        """
        COMPANY_TYPE_UNSPECIFIED = 0
        ADVERTISER = 1
        HOUSE_ADVERTISER = 2
        AGENCY = 3
        HOUSE_AGENCY = 4
        AD_NETWORK = 5


class CompanyCreditStatusEnum(proto.Message):
    r"""Wrapper message for
    [CompanyCreditStatus][google.ads.admanager.v1.CompanyCreditStatusEnum.CompanyCreditStatus]

    """

    class CompanyCreditStatus(proto.Enum):
        r"""The credit status of a company.

        Credit statuses specify the credit-worthiness of a company and
        affect the ad serving of campaigns belonging to the company.

        In basic settings, only the
        [ACTIVE][google.ads.admanager.v1.CompanyCreditStatusEnum.CompanyCreditStatus.ACTIVE]
        and
        [INACTIVE][google.ads.admanager.v1.CompanyCreditStatusEnum.CompanyCreditStatus.INACTIVE]
        credit statuses are applicable. In advance settings, all credit
        statuses are applicable.

        Values:
            COMPANY_CREDIT_STATUS_UNSPECIFIED (0):
                No value specified
            ACTIVE (1):
                The company's credit status is active.

                Line items belonging to the company can serve.

                This credit status is the default for basic
                settings and is available in both basic and
                advance settings.
            INACTIVE (2):
                The company's credit status is inactive.

                Line items belonging to the company cannot be
                activated. However, line items that were
                activated before the credit status changed will
                remain active. New orders or line items
                belonging to the company cannot be created.

                Companies with this credit status will be hidden
                by default in company search results.

                This credit status is available in both basic
                and advance settings.
            ON_HOLD (3):
                The company's credit status is on hold.

                Line items belonging to the company cannot be
                activated. However, line items that were
                activated before the credit status changed will
                remain active. New orders or line items
                belonging to the company can be created.

                This credit status is the default in advance
                settings and is only available in advance
                settings.
            STOP (4):
                The company's credit status is stopped.

                Line items belonging to the company cannot be
                activated. However, line items that were
                activated before the credit status changed will
                remain active. New orders or line items
                belonging to the company cannot be created.

                This credit status is only available in advance
                settings.
            BLOCKED (5):
                The company's credit status is blocked.

                All active line items belonging to the company
                will stop serving with immediate effect. Line
                items belonging to the company cannot be
                activated, and new orders or line items
                belonging to the company cannot be created.

                This credit status is only available in advance
                settings.
        """
        COMPANY_CREDIT_STATUS_UNSPECIFIED = 0
        ACTIVE = 1
        INACTIVE = 2
        ON_HOLD = 3
        STOP = 4
        BLOCKED = 5


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import order_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GetOrderRequest",
        "ListOrdersRequest",
        "ListOrdersResponse",
    },
)


class GetOrderRequest(proto.Message):
    r"""Request object for ``GetOrder`` method.

    Attributes:
        name (str):
            Required. The resource name of the Order. Format:
            ``networks/{network_code}/orders/{order_id}``
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListOrdersRequest(proto.Message):
    r"""Request object for ``ListOrders`` method.

    Attributes:
        parent (str):
            Required. The parent, which owns this collection of Orders.
            Format: ``networks/{network_code}``
        page_size (int):
            Optional. The maximum number of ``Orders`` to return. The
            service may return fewer than this value. If unspecified, at
            most 50 ``Orders`` will be returned. The maximum value is
            1000; values greater than 1000 will be coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListOrders`` call. Provide this to retrieve the subsequent
            page.

            When paginating, all other parameters provided to
            ``ListOrders`` must match the call that provided the page
            token.
        filter (str):
            Optional. Expression to filter the response.
            See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters
        order_by (str):
            Optional. Expression to specify sorting
            order. See syntax details at
            https://developers.google.com/ad-manager/api/beta/filters#order
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    parent: str = proto.Field(
        proto.STRING,
        number=1,
    )
    page_size: int = proto.Field(
        proto.INT32,
        number=2,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=3,
    )
    filter: str = proto.Field(
        proto.STRING,
        number=4,
    )
    order_by: str = proto.Field(
        proto.STRING,
        number=5,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=6,
    )


class ListOrdersResponse(proto.Message):
    r"""Response object for ``ListOrdersRequest`` containing matching
    ``Order`` resources.

    Attributes:
        orders (MutableSequence[google.ads.admanager_v1.types.Order]):
            The ``Order`` from the specified network.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of ``Orders``. If a filter was included in the
            request, this reflects the total number after the filtering
            is applied.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    orders: MutableSequence[order_messages.Order] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=order_messages.Order,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import any_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "AdManagerError",
    },
)


class AdManagerError(proto.Message):
    r"""/ AdManagerError contains all the information required for
    processing a / particular error thrown by the AdManager API. /
    / At least one AdManagerError should be included in all error
    messages sent to / the client.

    Attributes:
        error_code (str):
            The unique identifying string for this error.
        message (str):
            A publisher appropriate explanation of this
            error.
        field_path (str):
            The field path that triggered this error.
        trigger (str):
            The value that triggered this error.
        stack_trace (str):
            The stack trace that accompanies this error.
        details (MutableSequence[google.protobuf.any_pb2.Any]):
            A list of messages that carry any additional
            error details.
    """

    error_code: str = proto.Field(
        proto.STRING,
        number=1,
    )
    message: str = proto.Field(
        proto.STRING,
        number=2,
    )
    field_path: str = proto.Field(
        proto.STRING,
        number=3,
    )
    trigger: str = proto.Field(
        proto.STRING,
        number=4,
    )
    stack_trace: str = proto.Field(
        proto.STRING,
        number=5,
    )
    details: MutableSequence[any_pb2.Any] = proto.RepeatedField(
        proto.MESSAGE,
        number=6,
        message=any_pb2.Any,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

from google.protobuf import timestamp_pb2  # type: ignore
from google.type import money_pb2  # type: ignore
import proto  # type: ignore

from google.ads.admanager_v1.types import (
    deal_buyer_permission_type_enum,
    private_marketplace_enums,
    size,
)
from google.ads.admanager_v1.types import targeting as gaa_targeting

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "PrivateAuctionDeal",
    },
)


class PrivateAuctionDeal(proto.Message):
    r"""The ``PrivateAuctionDeal`` resource.

    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields

    Attributes:
        name (str):
            Identifier. The resource name of the ``PrivateAuctionDeal``.
            Format:
            ``networks/{network_code}/privateAuctionDeals/{private_auction_deal_id}``
        private_auction_deal_id (int):
            Output only. ``PrivateAuctionDeal`` ID.

            This field is a member of `oneof`_ ``_private_auction_deal_id``.
        private_auction_id (int):
            Immutable. The ID of the
            `PrivateAuction <google.ads.admanager.v1.PrivateAuction>`__.

            This field is a member of `oneof`_ ``_private_auction_id``.
        private_auction_display_name (str):
            Output only. The display name of the
            `PrivateAuction <google.ads.admanager.v1.PrivateAuction>`__.

            This field is a member of `oneof`_ ``_private_auction_display_name``.
        buyer_account_id (int):
            Immutable. The account ID of the buyer of the
            ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_buyer_account_id``.
        external_deal_id (int):
            Output only. The external ID of the ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_external_deal_id``.
        targeting (google.ads.admanager_v1.types.Targeting):
            Optional. The targeting of the ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_targeting``.
        end_time (google.protobuf.timestamp_pb2.Timestamp):
            Optional. The end time of the ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_end_time``.
        floor_price (google.type.money_pb2.Money):
            Required. The floor price of the ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_floor_price``.
        creative_sizes (MutableSequence[google.ads.admanager_v1.types.Size]):
            Optional. The expected creative sizes of the
            ``PrivateAuctionDeal``.
        status (google.ads.admanager_v1.types.PrivateMarketplaceDealStatusEnum.PrivateMarketplaceDealStatus):
            Output only. The status of the ``PrivateAuctionDeal``.

            This field is a member of `oneof`_ ``_status``.
        auction_priority_enabled (bool):
            Optional. Whether the deal is enabled with
            priority over open auction.

            This field is a member of `oneof`_ ``_auction_priority_enabled``.
        block_override_enabled (bool):
            Optional. Whether the deal has block override
            enabled.

            This field is a member of `oneof`_ ``_block_override_enabled``.
        buyer_permission_type (google.ads.admanager_v1.types.DealBuyerPermissionTypeEnum.DealBuyerPermissionType):
            Optional. The buyer permission model defining
            how the deal would transact among all buyers
            under the same bidder.

            This field is a member of `oneof`_ ``_buyer_permission_type``.
        buyer_data (google.ads.admanager_v1.types.PrivateAuctionDeal.BuyerData):
            Optional. The buyer data required by the
            Marketplace API.

            This field is a member of `oneof`_ ``_buyer_data``.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the ``PrivateAuctionDeal``
            was created.

            This field is a member of `oneof`_ ``_create_time``.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The instant at which the ``PrivateAuctionDeal``
            was last updated.

            This field is a member of `oneof`_ ``_update_time``.
    """

    class BuyerData(proto.Message):
        r"""Contains buyer data. This data is required by the Marketplace
        API.

        Attributes:
            buyer_emails (MutableSequence[str]):
                Optional. The email contacts of the buyer of the
                ``PrivateAuctionDeal``.
        """

        buyer_emails: MutableSequence[str] = proto.RepeatedField(
            proto.STRING,
            number=1,
        )

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    private_auction_deal_id: int = proto.Field(
        proto.INT64,
        number=2,
        optional=True,
    )
    private_auction_id: int = proto.Field(
        proto.INT64,
        number=3,
        optional=True,
    )
    private_auction_display_name: str = proto.Field(
        proto.STRING,
        number=20,
        optional=True,
    )
    buyer_account_id: int = proto.Field(
        proto.INT64,
        number=4,
        optional=True,
    )
    external_deal_id: int = proto.Field(
        proto.INT64,
        number=5,
        optional=True,
    )
    targeting: gaa_targeting.Targeting = proto.Field(
        proto.MESSAGE,
        number=6,
        optional=True,
        message=gaa_targeting.Targeting,
    )
    end_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=8,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    floor_price: money_pb2.Money = proto.Field(
        proto.MESSAGE,
        number=9,
        optional=True,
        message=money_pb2.Money,
    )
    creative_sizes: MutableSequence[size.Size] = proto.RepeatedField(
        proto.MESSAGE,
        number=18,
        message=size.Size,
    )
    status: private_marketplace_enums.PrivateMarketplaceDealStatusEnum.PrivateMarketplaceDealStatus = proto.Field(
        proto.ENUM,
        number=10,
        optional=True,
        enum=private_marketplace_enums.PrivateMarketplaceDealStatusEnum.PrivateMarketplaceDealStatus,
    )
    auction_priority_enabled: bool = proto.Field(
        proto.BOOL,
        number=11,
        optional=True,
    )
    block_override_enabled: bool = proto.Field(
        proto.BOOL,
        number=12,
        optional=True,
    )
    buyer_permission_type: deal_buyer_permission_type_enum.DealBuyerPermissionTypeEnum.DealBuyerPermissionType = proto.Field(
        proto.ENUM,
        number=13,
        optional=True,
        enum=deal_buyer_permission_type_enum.DealBuyerPermissionTypeEnum.DealBuyerPermissionType,
    )
    buyer_data: BuyerData = proto.Field(
        proto.MESSAGE,
        number=14,
        optional=True,
        message=BuyerData,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=15,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=16,
        optional=True,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "TaxonomyTypeEnum",
    },
)


class TaxonomyTypeEnum(proto.Message):
    r"""Wrapper for
    [TaxonomyType][google.ads.admanager.v1.TaxonomyTypeEnum.TaxonomyType]

    """

    class TaxonomyType(proto.Enum):
        r"""The taxonomy type of the IAB defined taxonomies.
        Used for Publisher provided signals.

        Values:
            TAXONOMY_TYPE_UNSPECIFIED (0):
                Unspecified/not present
            TAXONOMY_IAB_AUDIENCE_1_1 (3):
                The IAB Audience Taxonomy v1.1.
            TAXONOMY_IAB_CONTENT_1_0 (8):
                The IAB Content Taxonomy v1.0.
            TAXONOMY_IAB_CONTENT_2_1 (4):
                The IAB Content Taxonomy v2.1.
            TAXONOMY_IAB_CONTENT_2_2 (6):
                The IAB Content Taxonomy v2.2.
            TAXONOMY_IAB_CONTENT_3_0 (5):
                The IAB Content Taxonomy v3.0.
            TAXONOMY_GOOGLE_STRUCTURED_VIDEO_1_0 (7):
                The PPS structured video signals taxonomy.
        """
        TAXONOMY_TYPE_UNSPECIFIED = 0
        TAXONOMY_IAB_AUDIENCE_1_1 = 3
        TAXONOMY_IAB_CONTENT_1_0 = 8
        TAXONOMY_IAB_CONTENT_2_1 = 4
        TAXONOMY_IAB_CONTENT_2_2 = 6
        TAXONOMY_IAB_CONTENT_3_0 = 5
        TAXONOMY_GOOGLE_STRUCTURED_VIDEO_1_0 = 7


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

from google.ads.admanager_v1.types import network_messages

__protobuf__ = proto.module(
    package="google.ads.admanager.v1",
    manifest={
        "GetNetworkRequest",
        "ListNetworksRequest",
        "ListNetworksResponse",
    },
)


class GetNetworkRequest(proto.Message):
    r"""Request to get Network

    Attributes:
        name (str):
            Required. Resource name of Network. Format:
            networks/{network_code}
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )


class ListNetworksRequest(proto.Message):
    r"""Request object for ``ListNetworks`` method.

    Attributes:
        page_size (int):
            Optional. The maximum number of ``Network``\ s to return.
            The service may return fewer than this value. If
            unspecified, at most 50 ``Network``\ s will be returned. The
            maximum value is 1000; values greater than 1000 will be
            coerced to 1000.
        page_token (str):
            Optional. A page token, received from a previous
            ``ListNetworks`` call. Provide this to retrieve the
            subsequent page.

            When paginating, all other parameters provided to
            ``ListNetworks`` must match the call that provided the page
            token.
        skip (int):
            Optional. Number of individual resources to
            skip while paginating.
    """

    page_size: int = proto.Field(
        proto.INT32,
        number=3,
    )
    page_token: str = proto.Field(
        proto.STRING,
        number=4,
    )
    skip: int = proto.Field(
        proto.INT32,
        number=5,
    )


class ListNetworksResponse(proto.Message):
    r"""Response object for ``ListNetworks`` method.

    Attributes:
        networks (MutableSequence[google.ads.admanager_v1.types.Network]):
            The ``Network``\ s a user has access to.
        next_page_token (str):
            A token, which can be sent as ``page_token`` to retrieve the
            next page. If this field is omitted, there are no subsequent
            pages.
        total_size (int):
            Total number of ``Network``\ s.

            ``total_size`` won't be calculated in the response unless it
            has been included in a response field mask. The response
            field mask can be provided to the method by using the URL
            parameter ``$fields`` or ``fields``, or by using the
            HTTP/gRPC header ``X-Goog-FieldMask``.

            For more information, see
            https://developers.google.com/ad-manager/api/beta/field-masks
    """

    @property
    def raw_page(self):
        return self

    networks: MutableSequence[network_messages.Network] = proto.RepeatedField(
        proto.MESSAGE,
        number=1,
        message=network_messages.Network,
    )
    next_page_token: str = proto.Field(
        proto.STRING,
        number=2,
    )
    total_size: int = proto.Field(
        proto.INT32,
        number=3,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
